This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] search.c: Fix comment typos.


Hi,

Committed as obvious.

Kazu Hirata

2004-10-12  Kazu Hirata  <kazu@cs.umass.edu>

	* search.c: Fix comment typos.

Index: search.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/search.c,v
retrieving revision 1.330
diff -u -r1.330 search.c
--- search.c	11 Oct 2004 16:36:03 -0000	1.330
+++ search.c	12 Oct 2004 13:22:03 -0000
@@ -286,7 +286,7 @@
 		     derived.  */
   tree offset;    /* Best hint offset discovered so far.  */
   bool repeated_base;  /* Whether there are repeated bases in the
-			  heirarchy.  */
+			  hierarchy.  */
 };
 
 /* Worker for dcast_base_hint.  Search for the base type being cast
@@ -1722,7 +1722,7 @@
     {
       if (!BINFO_INHERITANCE_CHAIN (binfo))
 	{
 	  /* We are at the top of the hierachy, and can use the
              CLASSTYPE_VBASECLASSES list for unmarking the virtual
              bases.  */
 	  VEC (tree) *vbases;
@@ -1722,7 +1722,7 @@
       if (!BINFO_INHERITANCE_CHAIN (binfo))
 	{
-	  /* We are at the top of the hierachy, and can use the
+	  /* We are at the top of the hierarchy, and can use the
              CLASSTYPE_VBASECLASSES list for unmarking the virtual
              bases.  */


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]